* ------------------------------------------------
* Problem Set Solution: CMNS Matrix Multiplication
* ------------------------------------------------

* Matrix multiplication: Iterate over investors and asset classes
foreach investor in "USA" "EMU" "CAN" "GBR" "AUS" "DNK" "NOR" "SWE" "CHE" {

    use "$raw/Country_Portfolios_Nationality", clear
    qui drop if Investor == "USA" & Asset_Class_Code == "B"
    qui levelsof Asset_Class_Code if Investor == "`investor'", local(classes)
    foreach class of local classes {
        
        * Set locals
        di "Processing `investor' - `class'"
        if inlist("`class'", "E", "EF") {
            local matrix_class = "Equities"
        }
        if inlist("`class'", "BC") {
            local matrix_class = "Corporate_Bonds"
        }
        if inlist("`class'", "B") {
            local matrix_class = "All_Bonds"
        }
        if inlist("`class'", "BG") {
            local matrix_class = "Sovereign_Agency_Muni_Bonds"
        }       
        if inlist("`class'", "BSF") {
            local matrix_class = "Asset_Backed_Securities"
        }
        
        * Import matrices
        forval year = 2007/2017 {

        	* Read and reshape
            import excel using "$raw/Reallocation_Matrices/Reallocation_Matrix_`investor'_`matrix_class'_`year'.xls", clear firstrow
            rename * share*
            rename shareA Residency
            qui reshape long share, i(Residency) j(Nationality) string
            qui replace share = share / 100

			* Don't reallocate LUX for CPIS countries            
            qui replace share = 1 if "`class'" == "EF" & "`investor'" != "USA" & Residency == "LUX" & Nationality == "LUX"
            qui replace share = 0 if "`class'" == "EF" & "`investor'" != "USA" & Residency == "LUX" & Nationality != "LUX"
            gen Year = `year'
            qui save "$inter/matrix_long_`year'", replace
        }
        clear
        forval year = 2007/2017 {
            append using "$inter/matrix_long_`year'"
        }
        sort Year Residency
        save "$inter/matrix_long.dta", replace

        * Reconstruct positions
        use "$raw/Country_Portfolios_Nationality", clear
		*Do not reallocate equity investment from Luxembourg
        qui replace Position_Residency = 0 if Investor == "EMU" & Issuer == "LUX" & Asset_Class_Code == "EF"
        keep if Investor == "`investor'"
        keep if Asset_Class_Code == "`class'"
        keep Year Investor Asset_Class_Code Issuer Position_Residency
        rename Issuer Residency
        qui mmerge Year Residency using $inter/matrix_long.dta, unmatched(m)
        qui replace share = 1 if _merge == 1
        qui replace Nationality = Residency if _merge == 1
        drop _merge
        gen share_th_only = share
        gen th = 0
        qui replace th = 1 if inlist(Residency, $tax_haven1) | inlist(Residency, $tax_haven2) | inlist(Residency, $tax_haven3) | inlist(Residency, $tax_haven4) | inlist(Residency, $tax_haven5) | inlist(Residency, $tax_haven6) | inlist(Residency, $tax_haven7) | inlist(Residency, $tax_haven8)
        qui replace share_th_only = 1 if th == 0 & Residency == Nationality
        qui replace share_th_only = 0 if th == 0 & Residency != Nationality
        gen Position_Nationality_Full = share * Position_Residency
        gen Position_Nationality_TH_Only = share_th_only * Position_Residency
        save "$inter/new_rescaled_flows_`investor'_`class'", replace
        gcollapse (sum) Position_Nationality_Full Position_Nationality_TH_Only, by(Year Nationality)
        save "$inter/reconstructed_positions", replace

        * Merge with original file
        use "$raw/Country_Portfolios_Nationality", clear
        qui replace Position_Residency = 0 if Investor == "EMU" & Issuer == "LUX" & Asset_Class_Code == "EF"
        keep if Investor == "`investor'"
        keep if Asset_Class_Code == "`class'"
        keep Year Investor Asset_Class_Code Issuer Position_Nationality_Full Position_Nationality_TH_Only
        rename Issuer Nationality
        qui mmerge Year Nationality using "$inter/reconstructed_positions.dta", unmatched(m) uname(R_)
        drop _merge
        gsort -Year -Position_Nationality_TH_Only
        foreach var of varlist *Position* {
            qui replace `var' = `var' / 1e3
        }
        save "$inter/reconstruction_`investor'_`class'", replace

    }
}

* Append all reconstructions
cap restore
clear
preserve
foreach investor in "USA" "EMU" "CAN" "GBR" "AUS" "DNK" "NOR" "SWE" "CHE" {

    use "$raw/Country_Portfolios_Nationality", clear
    qui drop if Investor == "USA" & Asset_Class_Code == "B"
    qui levelsof Asset_Class_Code if Investor == "`investor'", local(classes)
    foreach class of local classes {
        restore
        append using "$inter/reconstruction_`investor'_`class'"
        preserve
    }
}
rename Nationality Issuer
label var Position_Nationality_Full "Full Nationality"
label var Position_Nationality_TH_Only "Nationality - Tax Haven Only"
save "$output/CMNS_Replication_Exercise_2a", replace
