* ------------------------------------------------
* Problem Set Solution: MNS Home Currency Bias
* ------------------------------------------------
local standard_errors "r"
local wls_command=" [aweight=total_country_currency]"
use "$raw/GCAP_FundHoldingsStatistics/DTA/Aggregate_Positions.dta", clear
gen corp_total=share_corp_bonds*mns_total
keep year investor corp_total
mmerge year investor using "$raw/GCAP_FundHoldingsStatistics/DTA/Bilateral_Country_Shares_corp_nationality_full.dta"

mmerge year investor issuer_nationality using  "$raw/GCAP_FundHoldingsStatistics/DTA/Bilateral_currency_Shares_corp_nationality_full.dta"
drop _merge
gen country_currency_share=portfolio_share*share

rename corp_total investor_corp_total
drop investor_name issuer_nationality_name currency_name
gen country_currency_level=investor_corp_total*country_currency_share
bysort issuer currency year: egen total_country_currency=sum(country_currency_level)

gen s_i_j_curr=country_currency_level/total_country_currency
gen ind=0
replace ind=1 if investor==issuer
gen currind=0
replace currind=1 if investor=="AUS" & currency=="AUD"
replace currind=1 if investor=="CAN" & currency=="CAD"
replace currind=1 if investor=="CHE" & currency=="CHF"
replace currind=1 if investor=="DNK" & currency=="DKK"
replace currind=1 if investor=="EMU" & currency=="EUR"
replace currind=1 if investor=="GBR" & currency=="GBP"
replace currind=1 if investor=="NOR" & currency=="NOK"
replace currind=1 if investor=="SWE" & currency=="SEK"
replace currind=1 if investor=="USA" & currency=="USD"

gen keep=0
foreach x of global issuers {
	replace keep=1 if issuer=="`x'"
}
keep if keep==1	
	
	
rename investor Dom
cap erase "$inter/homebias.xls"
cap erase "$inter/homebias.txt"
cap erase "$inter/homebias.dta"
cap erase "$inter/homebias.tex"

			levelsof (Dom), local (Dom)
			foreach x of local Dom {
			
				*Table 4: Home-Country Bias and Home-Currency Bias
				reg s_i_j_curr ind `wls_command' if Dom=="`x'" & year==2017, `standard_errors'
				outreg2 using "$inter/homebias.xls", keep(ind) dec(3) ctitle("`x'")  excel tex dta		
				reg s_i_j_curr currind  `wls_command' if Dom=="`x'" & year==2017, `standard_errors'
				outreg2 using "$inter/homebias.xls", keep(currind) dec(3) ctitle("`x'")    excel tex dta			
				reg s_i_j_curr ind currind `wls_command' if Dom=="`x'" & year==2017, `standard_errors'
				outreg2 using "$inter/homebias.xls", keep(ind currind) dec(3) ctitle("`x'")  excel tex dta	
				}



*Format Table 4: Home-Country Bias and Home-Currency Bias
use "$inter/homebias_dta.dta", clear
sxpose, clear
keep _var2 _var4 _var6 _var12
rename _var2 iso
rename _var4 country
rename _var6 currency
rename _var12 r2
drop if _n==1
gen n=_n
save "$inter/homebias_temp.dta", replace


use "$inter/homebias_temp.dta", clear
keep if mod(n,3)==1
keep iso country r2
foreach x in country r2 {
rename `x' spec1_`x'
}
save "$inter/homebias_1.dta", replace


use "$inter/homebias_temp.dta", clear
keep if mod(n,3)==2
keep iso currency r2
foreach x in currency r2 {
rename `x' spec2_`x'
}
save "$inter/homebias_2.dta", replace


use "$inter/homebias_temp.dta", clear
keep if mod(n,3)==0
keep iso country currency r2
foreach x in country currency r2 {
rename `x' spec3_`x'
}
save "$inter/homebias_3.dta", replace


use  "$inter/homebias_1.dta", clear
mmerge iso using "$inter/homebias_2.dta"
mmerge iso using "$inter/homebias_3.dta"
drop _merge


forvalues x=1/6 {
	gen s`x'=""
}	


order iso s1 s2 spec1_country spec1_r2 s3 s4 spec2_currency spec2_r2 s5 s6 spec3_country spec3_currency spec3_r2
save "$inter/homebias.dta", replace
append using  "$inter/homebias.dta"
sort iso
forvalues i=2(2)20 {
	foreach x of varlist _all {
		replace `x'="" if _n==`i'
	}
}

export excel using "$results/homebias_table_2017.xls", firstrow(variables) replace
